@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * LV2 bridging helper library
  *
- * Copyright (C) 2007-2011 NASPRO Bridge it development team
+ * Copyright (C) 2007-2012 NASPRO Bridge it development team
  *
  * See the COPYING file for license conditions.
  */
@@ -10,7 +10,7 @@
 /*
    Title: NASPRO Bridge it
 
-   *Version*: 0.3.0, *API*: 2.0.0.
+   *Version*: 0.4.0, *API*: 2.0.1.
 
    About:
 
@@ -19,18 +19,17 @@
 
      As of now, it basically offers a few utility functions and Turtle/RDF
      serialization for LV2 dynamic manifest generation, supporting the following
-     LV2 specifications/extensions.
+     LV2 extensions.
 
-       * <LV2 at http://lv2plug.in/ns/lv2core> version 4.0;
-       * <LV2 Dynamic Manifest at http://lv2plug.in/ns/ext/dyn-manifest> version
-         1.0;
-       * <LV2 Port Properties at http://lv2plug.in/ns/ext/port-props> version
-         0.1 (only for the logarithmic port property);
+       * <LV2 at http://lv2plug.in/ns/lv2core> >= 4.0;
+       * <LV2 Dynamic Manifest at http://lv2plug.in/ns/ext/dynmanifest> >= 1.0;
+       * <LV2 Port Properties at http://lv2plug.in/ns/ext/port-props> >= 0.1
+         (only for the logarithmic port property);
        * <Extended Port Information at http://lv2plug.in/ns/dev/extportinfo>
          draft revision 3 (only for the logarithmic port property, deprecated);
-       * <LV2 Events at http://lv2plug.in/ns/ext/event> version 1.0;
-       * <LV2 MIDI Events at http://lv2plug.in/ns/ext/midi> version 1.0;
-       * <LV2 Presets at http://lv2plug.in/ns/ext/presets> version 2.2.
+       * <LV2 Events at http://lv2plug.in/ns/ext/event> >= 1.0;
+       * <LV2 MIDI Events at http://lv2plug.in/ns/ext/midi> >= 1.0;
+       * <LV2 Presets at http://lv2plug.in/ns/ext/presets> >= 2.2.
 
    Supported platforms/compilers:
 
@@ -51,15 +50,15 @@
    Runtime dependencies:
 
      * <NASPRO core at http://naspro.atheme.org/libraries/naspro-core/> >=
-       0.3.0.
+       0.4.0.
 
    Build-time dependencies:
 
-     * <LV2 core at http://lv2plug.in> >= 4.0;
+     * <LV2 at http://lv2plug.in> >= 4.0;
      * <pkg-config at http://pkg-config.freedesktop.org/>;
      * An environment capable of running Autotools-based build systems;
      * (optional) <GNU Autoconf at http://www.gnu.org/software/autoconf/> >=
-       2.61, <GNU Automake at http://www.gnu.org/software/automake/> and
+       2.68, <GNU Automake at http://www.gnu.org/software/automake/> and
        <GNU Libtool at http://www.gnu.org/software/libtool/> to regenerate the
        build system;
      * (optional) <Natural Docs at http://www.naturaldocs.org/> >= 1.5 to
