@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * LV2 bridging helper library
  *
- * Copyright (C) 2007-2011 NASPRO Bridge it development team
+ * Copyright (C) 2007-2012 NASPRO Bridge it development team
  *
  * See the COPYING file for license conditions.
  */
@@ -79,9 +79,12 @@ _NABRIT_DEF void
 nabrit_manifest_print_subjects(nabrit_bridge bridge, FILE *fp)
 {
 	nacore_avl_tree_elem elem;
+	nacore_list_elem pelem;
 	nabrit_plugin plugin;
+	size_t i;
 
 	fprintf(fp, "@prefix lv2:  <http://lv2plug.in/ns/lv2core#> .\n");
+	fprintf(fp, "@prefix pset: <http://lv2plug.in/ns/ext/presets#> .\n");
 
 	for (elem = nacore_avl_tree_get_first(bridge->plugins); elem != NULL;
 	     elem = nacore_avl_tree_elem_get_next(bridge->plugins, elem))
@@ -91,6 +94,27 @@ nabrit_manifest_print_subjects(nabrit_bridge bridge, FILE *fp)
 		fprintf(fp, "<");
 		print_uriref(fp, plugin->descriptor.URI);
 		fprintf(fp, "> a lv2:Plugin .\n");
+
+		for (i = 0, pelem = nacore_list_get_head(plugin->presets);
+		     pelem != NULL;
+		     i++, pelem = nacore_list_elem_get_next(plugin->presets,
+							    pelem))
+		  {
+			fprintf(fp, "<");
+			print_uriref(fp, plugin->descriptor.URI);
+			fprintf(fp, "/presets/preset%"
+				    NACORE_LIBC_SIZE_FORMAT_LM "u> a "
+				    "pset:Preset ;\n",
+				    (NACORE_LIBC_SIZE_FORMAT_TYPE)i);
+
+			fprintf(fp, "\tlv2:appliesTo <");
+			print_uriref(fp, plugin->descriptor.URI);
+			fprintf(fp, "> ;\n");
+
+			fprintf(fp, "\tpset:appliesTo <");
+			print_uriref(fp, plugin->descriptor.URI);
+			fprintf(fp, "> .\n");
+		  }
 	  }
 }
 
@@ -277,6 +301,10 @@ nabrit_manifest_print_data(nabrit_bridge bridge, FILE *fp, const char *URI)
 		print_string(fp, preset->name);
 		fprintf(fp, "\" ;\n");
 
+		fprintf(fp, "\tlv2:appliesTo <");
+		print_uriref(fp, plugin->descriptor.URI);
+		fprintf(fp, "> ;\n");
+
 		fprintf(fp, "\tpset:appliesTo <");
 		print_uriref(fp, plugin->descriptor.URI);
 		fprintf(fp, ">");
